@@ -1,6 +1,6 @@
 // use crate::utils::handle_response;
-use crate::{errors::{CrateResult, Error}, utils::handle_response};
-use reqwest::{IntoUrl, Response, StatusCode, Url};
+use crate::{errors::{CrateResult, Error}, utils::{handle_response, handle_response_alt}};
+use reqwest::{IntoUrl, Response, StatusCode, Url, multipart};
 use serde::{Serialize, de::DeserializeOwned};
 
 pub struct RestApiClientBuilder<ApiErrorType>
@@ -86,4 +86,21 @@ where
         let response = self.http_client.delete(url).send().await?;
         handle_response::<ResponseDataType, ApiErrorType>(response).await
     }
+
+    // pub async fn post_multipart<ResponseDataType>(&self, form: multipart::Form, path: &str) -> CrateResult<ResponseDataType>
+    // where
+    //     ResponseDataType: DeserializeOwned
+    // {
+    //     let url = self.api_base_url.to_string() + path;
+    //     let response = self.http_client.post(url).multipart(form).send().await?;
+    //     handle_response::<ResponseDataType, ApiErrorType>(response).await
+    // }
+
+    pub async fn post_multipart_alt(&self, form: multipart::Form, path: &str) -> CrateResult<()>
+    where
+    {
+        let url = self.api_base_url.to_string() + path;
+        let response = self.http_client.post(url).multipart(form).send().await?;
+        handle_response_alt::<ApiErrorType>(response).await
+    }
 }
\ No newline at end of file
