@@ -22,4 +22,21 @@ where
             Err(_) => { return Err(Error::UnexpectedData(body_text)) }
         }
     }
+}
+
+pub async fn handle_response_alt<ApiErrorType>(response: reqwest::Response) -> CrateResult<()>
+where
+    ApiErrorType: DeserializeOwned + ToString
+{
+    if response.status().is_success() {
+        return Ok(())
+    }
+    else {
+        let body_text = response.text().await?;
+        let maybe_api_error = serde_json::from_str::<ApiErrorType>(&body_text);
+        match maybe_api_error {
+            Ok(api_error) => { return Err(Error::ApiError(api_error.to_string())) }
+            Err(_) => { return Err(Error::UnexpectedData(body_text)) }
+        }
+    }
 }
\ No newline at end of file
